@@ -158,6 +158,7 @@ class Undouble():
             * 'phash': Perceptual hash
             * 'dhash': Difference hash
             * 'whash-haar': Haar wavelet hash
+            * 'crop-resistant-hash' : Crop resistance hash
         hash_size : integer (default: 8)
             The hash_size will be used to scale down the image and create a hash-image of length: hash_size*hash_size.
 
@@ -170,6 +171,9 @@ class Undouble():
         if method is not None:
             self.params['method'] = method
             self.clustimage.params['method'] = method
+        if method=='crop-resistant-hash':
+            logger.info('Hash size is set to 8 for crop-resistant and can not be changed.')
+            hash_size=8
         if hash_size is not None:
             self.params['hash_size'] = hash_size
             self.clustimage.params_hash['hash_size'] = hash_size
@@ -235,8 +239,8 @@ class Undouble():
 
         # Sort on threshold
         for i, _ in enumerate(thresholds):
-            # indexes[i] = indexes[i][isort]
-            isort=np.argsort(thresholds[i])
+            isort = np.argsort(thresholds[i])
+            indexes[i] = indexes[i][isort]
             pathnames[i] = pathnames[i][isort]
             thresholds[i] = thresholds[i][isort]
 
@@ -244,6 +248,7 @@ class Undouble():
         idx = np.argsort(list(map(lambda x: os.path.split(x[0])[0], pathnames)))
         self.results['select_pathnames'] = np.array(pathnames)[idx].tolist()
         self.results['select_scores'] = np.array(thresholds)[idx].tolist()
+        self.results['select_idx'] = indexes
         logger.info('[%d] groups with similar image-hash.' %(len(self.results['select_pathnames'])))
 
         totfiles = np.sum(list(map(len, self.results['select_pathnames'])))
